/*
 * -------------------------------------------------------------------- *
 *  STRONGMAIL SYSTEMS                                                  *
 *                                                                      *
 *  Copyright 2016 StrongMail Systems, Inc. - All rights reserved.      *
 *                                                                      *
 *  Visit http://www.strongmail.com for more information                *
 *                                                                      *
 *  You may incorporate this Source Code in your application only if    *
 *  you own a valid license to do so from StrongMail Systems, Inc.      *
 *  and the copyright notices are not removed from the source code.     *
 *                                                                      *
 *  Distributing our source code outside your organization              *
 *  is strictly prohibited                                              *
 *                                                                      *
 * -------------------------------------------------------------------- *
 */

package com.strongmail.restclient;


import com.jayway.restassured.RestAssured;
import com.jayway.restassured.builder.RequestSpecBuilder;
import com.jayway.restassured.http.ContentType;

import java.io.FileInputStream;
import java.io.FileNotFoundException;
import java.io.IOException;
import java.util.PropertyResourceBundle;


public class RestClientStore {

  private static final PropertyResourceBundle config;
  private static final String HOST_NAME = "host_name";
  private static final String PORT = "port";
  private static final String AUTHORIZATION_HEADER = "authorization_header";
  private static final String ORGANIZATION_HEADER = "organization_header";
  private static final String VERSION = "version";
  private static final String AUTHENTICATION_KEY = "authentication_key";
  private static final String ORGANIZATION_NAME = "organization";
  private static final String KEYSTORE_FILE = "keystore_file";
  private static final String KEYSTORE_PASSWORD = "keystore_password";
  private static final String MAILING_ID = "mailing_id";

  static {
    try {
      config = new PropertyResourceBundle(new FileInputStream("./rest.config"));

      // Set SSL certificate
      RestAssured.keystore(getKeyStoreFileName(), getKeyStorePassword());
    }
    catch(IOException e) {
      throw new RuntimeException("Unable to load configuration" + e.getMessage());
    }
  }

  public static String getHost() {
    return config.getString(HOST_NAME);
  }

  public static String getPort() {
    return config.getString(PORT);
  }

  public static String getAuthorizationHedar() {
    return config.getString(AUTHORIZATION_HEADER);
  }

  public static String getOrganizationHeder() {
    return config.getString(ORGANIZATION_HEADER);
  }

  public static String getAuthenticationKey() {
    return config.getString(AUTHENTICATION_KEY);
  }

  public static String getOrganization() {
    return config.getString(ORGANIZATION_NAME);
  }

  public static String getBaseUrl() {
    return "https://" + getHost() + ":" + getPort() + "/sm/rest/v1";
  }

  public static Long getMailingId() {
    try {
      return Long.parseLong(config.getString(MAILING_ID));
    }
    catch(Exception e) {
      System.out.println("Invalid mailing_id is specified/mailing_id is missing");
      return null;
    }
  }

  private static String getKeyStoreFileName() {
    return config.getString(KEYSTORE_FILE);
  }

  private static String getKeyStorePassword() {
    return config.getString(KEYSTORE_PASSWORD);
  }

  public static RequestSpecBuilder setup() {
    RequestSpecBuilder builder = new RequestSpecBuilder();

    // Add default headers
    builder.addHeader(getAuthorizationHedar(), getAuthenticationKey());
    // The department can be specified as [organization_name]/[department]
    builder.addHeader(getOrganizationHeder(), getOrganization());

    // Add content-type
    builder.setContentType(ContentType.JSON);
    return builder;
  }
}
